@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Run; # git description: 0.045-5-gca670d9
+package Dist::Zilla::Plugin::Run; # git description: 0.046-8-ga815959
 # ABSTRACT: Run external commands and code at specific phases of Dist::Zilla
 # KEYWORDS: plugin tool distribution build release run command shell execute
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 1;
 
@@ -21,7 +21,7 @@ Dist::Zilla::Plugin::Run - Run external commands and code at specific phases of
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -133,6 +133,21 @@ All commands for a given option name are executed together, in the order in
 which they are documented above.  Within commands of the same option name,
 order is preserved (from the order provided in F<dist.ini>).
 
+=head1 ENVIRONMENT
+
+=for stopwords subshell
+
+For executed commands, L<IPC::Open3/open3> is used -- there is no subshell.
+Consequently environment variables may or may not be available depending on
+the individual architecture used.  For Perl strings that are evaluated, they
+are done in the dzil process, so all current global variables and other state
+is available for use.
+
+The current working directory is undefined, and may vary depending on the
+version of Dist::Zilla being used. If the state of the filesystem is
+important, explicitly change directories first, or base your relative paths
+off of the build root (available as C<%d>, see below).
+
 =head1 CONVERSIONS
 
 The following conversions/format specifiers are defined
@@ -143,7 +158,11 @@ for passing as arguments to the specified commands and eval strings
 
 =item *
 
-C<%a> the archive of the release (only available to all C<*Release> phases)
+C<%a> the archive of the release (only available to all C<*Release> phases), as documented to be passed to BeforeRelease, Release, AfterRelease plugins
+
+=item *
+
+C<%o> the directory in which the distribution source originated
 
 =item *
 
