@@ -3,7 +3,7 @@ use warnings;
 package Dist::Zilla::Plugin::Run::Role::Runner;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.045';
+our $VERSION = '0.047';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -234,13 +234,25 @@ sub build_formatter {
     my $codes = {
         # not always available
         # explicitly pass a string (not an object) [rt-72008]
-        a => defined $params->{archive} ? "$params->{archive}" : '',
+        a => sub {
+            return "$params->{archive}" if defined $params->{archive};
+            $self->log('attempting to use %a in a non-Release plugin');
+            '';
+        },
+
+        # source dir
+        o => sub {
+            my $dir = $params->{source_dir} || $self->zilla->root;
+            return $dir ? "$dir" : '';
+        },
 
         # build dir or mint dir
         d => sub {
             # stringify build directory
             my $dir = $params->{dir} || $self->zilla->built_in;
-            $dir ? "$dir" : '';
+            return "$dir" if $dir;
+            $self->log('attempting to use %d in before_build');
+            '';
         },
 
         # distribution name
